@@ -1,11 +1,12 @@
 package App::ParseCPANChanges;
 
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.05'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.04'; # VERSION
-
 our %SPEC;
 
 $SPEC{parse_cpan_changes} = {
@@ -55,7 +56,7 @@ App::ParseCPANChanges - Parse CPAN Changes file
 
 =head1 VERSION
 
-This document describes version 0.04 of App::ParseCPANChanges (from Perl distribution App-ParseCPANChanges), released on 2014-07-22.
+This document describes version 0.05 of App::ParseCPANChanges (from Perl distribution App-ParseCPANChanges), released on 2015-09-03.
 
 =head1 DESCRIPTION
 
@@ -79,8 +80,6 @@ If not specified, will look for file called Changes/ChangeLog in current directo
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -90,7 +89,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 SEE ALSO
 
@@ -111,7 +110,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-ParseC
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-ParseCPANChanges>.
+Source repository is at L<https://github.com/perlancar/perl-App-ParseCPANChanges>.
 
 =head1 BUGS
 
@@ -123,11 +122,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
